/***************************************************************************
 *   Copyright (C) 2003 by Hideki Ikemoto                                  *
 *   ikemo@users.sourceforge.jp                                            *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 ***************************************************************************/

#include "category.h"

using namespace Kita;

Category::Category( const QString& name ) : m_name(name)
{
}

Category::~Category()
{
}

void Category::append( const Board* board )
{
  m_boardList.append( board );
}

const QPtrList<Board>& Category::getBoardList() const
{
  return m_boardList;
}

const QString& Category::name() const
{
  return m_name;
}
